=====================
ec2api tempest plugin
=====================

Tempest plugin ec2api_tempest_plugin

Please fill here a long description which must be at least 3 lines wrapped on
80 cols, so that distribution package maintainers can use it in their packages.
Note that this is a hard requirement.

* Free software: Apache license
* Documentation: https://docs.openstack.org/ec2-api/latest
* Source: https://opendev.org/openstack/ec2api-tempest-plugin
* Bugs: https://bugs.launchpad.net/ec2-api

Features
--------

* TODO
